@@ -1,11 +1,6 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2019 SoloKeys Developers
-#
-# Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-# http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-# http://opensource.org/licenses/MIT>, at your option. This file may not be
-# copied, modified, or distributed except according to those terms.
+# Copyright Nitrokey GmbH
+# SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import ctypes
 import functools
@@ -17,9 +12,8 @@ import time
 from getpass import getpass
 from importlib.metadata import version
 from itertools import chain
-from numbers import Number
 from threading import Event, Timer
-from typing import Any, Callable, Dict, List, NoReturn, Optional, Tuple, TypeVar, Union
+from typing import Any, Callable, List, Optional, Tuple, TypeVar, Union
 
 import click
 from nitrokey.updates import Repository
@@ -91,6 +85,19 @@ def from_websafe(data: str) -> str:
     return data + "=="[: (3 * len(data)) % 4]
 
 
+def b32padding(data: str) -> str:
+    """Helper function to pad base32 strings correctly, as some services
+    provide OTP secrets as base32 strings without the necessary padding
+
+    `s`: `str` base32 input string
+
+    Returns:
+        `str`: string padded to full base32 character blocks
+    """
+    padding_needed = 8 - (len(data) % 8)
+    return data + (padding_needed * "=")
+
+
 class ProgressBar:
     """
     Helper class for progress bars where the total length of the progress bar
